@@ -42,28 +42,26 @@ struct ether
     struct ether_addr addr;
 };
 
-
-#ifndef FINALOUT
-#define _setethent setethent
-#define _endethent endethent
-#define _getethent getethent
-#define _getethbyname getethbyname
-#define _getethbyaddr getethbyaddr
-#endif
-
 /* /etc/ethers file access functions */
 extern void _setethent(void);
 extern void _endethent(void);
 extern struct ether *_getethent(void);
-extern struct ether *_getethbyname(char *name);
-extern struct ether *_getethbyaddr(struct ether_addr *addr);
+extern struct ether *_getethbyname(const char *name);
+extern struct ether *_getethbyaddr(const struct ether_addr *addr);
+
+/* NameServiceSwitch indirect access functions */
+extern void setethent(void);
+extern void endethent(void);
+extern struct ether *getethent(void);
+extern struct ether *getethbyname(const char *name);
+extern struct ether *getethbyaddr(const struct ether_addr *addr);
 
 /* Client access functions */
-extern char *              ether_ntoa(struct ether_addr *addr);
-extern struct ether_addr * ether_aton(char *addr);
+extern char *              ether_ntoa(const struct ether_addr *addr);
+extern struct ether_addr * ether_aton(const char *addr);
 
-extern int ether_ntohost(char *hostname, struct ether_addr *addr);
-extern int ether_hostton(char *hostname, struct ether_addr *addr);
+extern int ether_ntohost(char *hostname, const struct ether_addr *addr);
+extern int ether_hostton(const char *hostname, struct ether_addr *addr);
 
 extern int ether_line(char *line, struct ether_addr *addr, char *hostname);
 
