@@ -58,27 +58,27 @@ static void CONCAT(_nsw_set,FUNCOBJENT)(int ptr)
 #ifdef ENABLE_NIS
       case NSWO_NISPLUS:
 #ifdef SETARGTYPE
-	CONCAT(nis_set,FUNCOBJENT)(saved_setarg, NULL);
+	CONCAT(nis_set,FUNCOBJENT)(saved_setarg);
 #else
-	CONCAT(nis_set,FUNCOBJENT)(NULL);
+	CONCAT(nis_set,FUNCOBJENT)();
 #endif
 	break;
 #endif
 #ifdef ENABLE_YP	    
       case NSWO_NIS:
 #ifdef SETARGTYPE
-	CONCAT(yp_set,FUNCOBJENT)(saved_setarg, NULL);
+	CONCAT(yp_set,FUNCOBJENT)(saved_setarg);
 #else
-	CONCAT(yp_set,FUNCOBJENT)(NULL);
+	CONCAT(yp_set,FUNCOBJENT)();
 #endif
 	break;
 #endif
 #ifdef ENABLE_DNS
       case NSWO_DNS:
 #ifdef SETARGTYPE
-	CONCAT(dns_set,FUNCOBJENT)(saved_setarg, NULL);
+	CONCAT(dns_set,FUNCOBJENT)(saved_setarg);
 #else
-	CONCAT(dns_set,FUNCOBJENT)(NULL);
+	CONCAT(dns_set,FUNCOBJENT)();
 #endif
 	break;
 #endif
@@ -93,14 +93,17 @@ void CONCAT(CONCAT(NSWPREFIX,set),FUNCOBJENT)
     (void)
 #endif
 {
+    static int CONCAT(recur_,FUNCOBJENT) = 0;
+
     setflag = 1;
     setptr  = 0;
     
     
+    
     if (nswp == NULL)
 	nswp = getnswbyname(NSWENTRY);
     
-    if (nswp == NULL)
+    if (CONCAT(recur_,FUNCOBJENT) == 1 || nswp == NULL)
     {
 #ifdef SETARGTYPE
 	CONCAT(SETPREFIX,FUNCOBJENT)(arg);
@@ -109,6 +112,8 @@ void CONCAT(CONCAT(NSWPREFIX,set),FUNCOBJENT)
 #endif
 	return;
     }
+    
+    CONCAT(recur_,FUNCOBJENT) = 1;
 
 #ifdef SETARGTYPE
 #ifdef SETARGDUP
@@ -119,6 +124,8 @@ void CONCAT(CONCAT(NSWPREFIX,set),FUNCOBJENT)
 #endif
     
     CONCAT(_nsw_set,FUNCOBJENT)(setptr);
+
+    CONCAT(recur_,FUNCOBJENT) = 0;
 }
 
 
