@@ -29,10 +29,10 @@
 #include <sys/types.h>
 #include <grp.h>
 
-void dns_setgrent(void *opts);
-void dns_endgrent(void *opts);
-struct group *dns_getgrent(void *opts);
-struct group *dns_getgrgid(gid_t gid, void *opts);
-struct group *dns_getgrnam(const char *name, void *opts);
+void dns_setgrent(void);
+void dns_endgrent(void);
+struct group *dns_getgrent(void);
+struct group *dns_getgrgid(gid_t gid);
+struct group *dns_getgrnam(const char *name);
 
 #endif
