@@ -33,31 +33,31 @@
 #include "dns_passwd.h"
 
 
-void dns_setpwent(void *opts)
+void dns_setpwent(void)
 {
 }
 
 
-void dns_endpwent(void *opts)
+void dns_endpwent(void)
 {
 }
 
 
-struct passwd *dns_getpwent(void *opts)
+struct passwd *dns_getpwent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct passwd *dns_getpwuid(uid_t uid, void *opts)
+struct passwd *dns_getpwuid(uid_t uid)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct passwd *dns_getpwnam(const char *name, void *opts)
+struct passwd *dns_getpwnam(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
