@@ -29,9 +29,9 @@
 #include <sys/types.h>
 #include <shadow.h>
 
-extern void dns_setspent(void *opts);
-extern void dns_endspent(void *opts);
-extern struct spwd *dns_getspent(void *opts);
-extern struct spwd *dns_getspnam(const char *name, void *opts);
+extern void dns_setspent(void);
+extern void dns_endspent(void);
+extern struct spwd *dns_getspent(void);
+extern struct spwd *dns_getspnam(const char *name);
 
 #endif
