@@ -30,31 +30,31 @@
 #include "nis_networks.h"
 
 
-void nis_setnetent(int stayopen, void *opts)
+void nis_setnetent(int stayopen)
 {
 }
 
 
-void nis_endnetent(void *opts)
+void nis_endnetent(void)
 {
 }
 
 
-struct netent *nis_getnetent(void *opts)
+struct netent *nis_getnetent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct netent *nis_getnetbyname(const char *name, void *opts)
+struct netent *nis_getnetbyname(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct netent *nis_getnetbyaddr(long net, int type, void *opts)
+struct netent *nis_getnetbyaddr(long net, int type)
 {
     errno = ECONNREFUSED;
     return NULL;
