@@ -33,31 +33,31 @@
 #include "nis_passwd.h"
 
 
-void nis_setpwent(void *opts)
+void nis_setpwent(void)
 {
 }
 
 
-void nis_endpwent(void *opts)
+void nis_endpwent(void)
 {
 }
 
 
-struct passwd *nis_getpwent(void *opts)
+struct passwd *nis_getpwent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct passwd *nis_getpwuid(uid_t uid, void *opts)
+struct passwd *nis_getpwuid(uid_t uid)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct passwd *nis_getpwnam(const char *name, void *opts)
+struct passwd *nis_getpwnam(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
