@@ -29,9 +29,9 @@
 #include <sys/types.h>
 #include <shadow.h>
 
-extern void nis_setspent(void *opts);
-extern void nis_endspent(void *opts);
-extern struct spwd *nis_getspent(void *opts);
-extern struct spwd *nis_getspnam(const char *name, void *opts);
+extern void nis_setspent(void);
+extern void nis_endspent(void);
+extern struct spwd *nis_getspent(void);
+extern struct spwd *nis_getspnam(const char *name);
 
 #endif
