@@ -42,7 +42,7 @@
 void _ENSWF(_setgrent)(void);
 void _ENSWF(_endgrent)(void);
 struct group * _ENSWF(_getgrent)(void);
-struct group * _ENSWF(_getgruid)(gid_t uid);
-struct group * _ENSWF(_getgrnam)(char *name);
+struct group * _ENSWF(_getgrgid)(gid_t gid);
+struct group * _ENSWF(_getgrnam)(const char *name);
 
 #endif
