@@ -42,7 +42,7 @@
 void _ENSWF(_sethostent)(int stayopen);
 void _ENSWF(_endhostent)(void);
 struct hostent * _ENSWF(_gethostent)(void);
-struct hostent * _ENSWF(_gethostbyname)(char *name);
-struct hostent * _ENSWF(_gethostbyaddr)(char *addr, int len, int type);
+struct hostent * _ENSWF(_gethostbyname)(const char *name);
+struct hostent * _ENSWF(_gethostbyaddr)(const char *addr, int len, int type);
 
 #endif
