@@ -108,7 +108,7 @@ static struct group *grent_parse(char *str, int len)
 }
 
 
-void yp_setgrent(char *opts)
+void yp_setgrent(void)
 {
     rewind_flag = 1;
     if (savekey)
@@ -116,7 +116,7 @@ void yp_setgrent(char *opts)
 }
 
 
-void yp_endgrent(char *opts)
+void yp_endgrent(void)
 {
     rewind_flag = 1;
     if (savekey)
@@ -124,7 +124,7 @@ void yp_endgrent(char *opts)
 }
 
 
-struct group *yp_getgrent(char *opts)
+struct group *yp_getgrent(void)
 {
     struct group *gr;
     char *map;
@@ -135,7 +135,7 @@ struct group *yp_getgrent(char *opts)
     int keylen;
 
 
-    map = _ypopts_getmd(opts, "group", ".byname", &domain);
+    map = _ypopts_getmd("group", ".byname", &domain);
     if (map == NULL)
 	return NULL;
 
@@ -175,7 +175,7 @@ struct group *yp_getgrent(char *opts)
 }
 
 
-struct group *yp_getgrgid(gid_t gid, char *opts)
+struct group *yp_getgrgid(gid_t gid)
 {
     struct group *gr;
     char *map;
@@ -185,7 +185,7 @@ struct group *yp_getgrgid(gid_t gid, char *opts)
     char buf[256];
 
 
-    map = _ypopts_getmd(opts, "group", ".bygid", &domain);
+    map = _ypopts_getmd("group", ".bygid", &domain);
     if (map == NULL)
 	return NULL;
 
@@ -206,7 +206,7 @@ struct group *yp_getgrgid(gid_t gid, char *opts)
 }
 
 
-struct group *yp_getgrnam(const char *name, char *opts)
+struct group *yp_getgrnam(const char *name)
 {
     struct group *gr;
     char *map;
@@ -214,7 +214,7 @@ struct group *yp_getgrnam(const char *name, char *opts)
     char *result;
     int len;
 
-    map = _ypopts_getmd(opts, "group", ".byname", &domain);
+    map = _ypopts_getmd("group", ".byname", &domain);
     if (map == NULL)
 	return NULL;
 
