@@ -49,8 +49,8 @@ static struct rpcent *rpcent_parse(char *str, int len)
     char *cp;
     int alen;
     int i;
-    
-    
+
+
     if (Xalloc(&pbuf, len+8) == NULL)
 	return NULL;
     
@@ -90,7 +90,7 @@ static struct rpcent *rpcent_parse(char *str, int len)
 
 
 
-void yp_setrpcent(int stayopen, void *opts)
+void yp_setrpcent(int stayopen)
 {
     rewind_flag = 1;
     if (savekey)
@@ -98,7 +98,7 @@ void yp_setrpcent(int stayopen, void *opts)
 }
 
 
-void yp_endrpcent(void *opts)
+void yp_endrpcent(void)
 {
     rewind_flag = 1;
     if (savekey)
@@ -106,7 +106,7 @@ void yp_endrpcent(void *opts)
 }
 
 
-struct rpcent *yp_getrpcent(void *opts)
+struct rpcent *yp_getrpcent(void)
 {
     struct rpcent *rpe;
     char *map;
@@ -117,7 +117,7 @@ struct rpcent *yp_getrpcent(void *opts)
     int keylen;
 
 
-    map = _ypopts_getmd(opts, "rpc", ".byname", &domain);
+    map = _ypopts_getmd("rpc", ".byname", &domain);
     if (map == NULL)
 	return NULL;
 
@@ -179,8 +179,7 @@ struct rpcent *yp_getrpcent(void *opts)
 }
 
 
-struct rpcent *yp_getrpcbyname(const char *name,
-			       void *opts)
+struct rpcent *yp_getrpcbyname(const char *name)
 {
     struct rpcent *rpp;
     char *map;
@@ -189,7 +188,7 @@ struct rpcent *yp_getrpcbyname(const char *name,
     int len;
 
 
-    map = _ypopts_getmd(opts, "rpc", ".byname", &domain);
+    map = _ypopts_getmd("rpc", ".byname", &domain);
     if (map == NULL)
 	return NULL;
 
@@ -208,7 +207,7 @@ struct rpcent *yp_getrpcbyname(const char *name,
 }
 
 
-struct rpcent *yp_getrpcbynumber(int number, void *opts)
+struct rpcent *yp_getrpcbynumber(int number)
 {
     char buf[32];
     struct rpcent *rpp;
@@ -218,7 +217,7 @@ struct rpcent *yp_getrpcbynumber(int number, void *opts)
     int len;
 
 
-    map = _ypopts_getmd(opts, "protocols", ".bynumber", &domain);
+    map = _ypopts_getmd("protocols", ".bynumber", &domain);
     if (map == NULL)
 	return NULL;
 
