@@ -29,9 +29,9 @@
 #include <sys/types.h>
 #include <shadow.h>
 
-extern void yp_setspent(void *opts);
-extern void yp_endspent(void *opts);
-extern struct spwd *yp_getspent(void *opts);
-extern struct spwd *yp_getspnam(const char *name, void *opts);
+extern void yp_setspent(void);
+extern void yp_endspent(void);
+extern struct spwd *yp_getspent(void);
+extern struct spwd *yp_getspnam(const char *name);
 
 #endif
