@@ -33,12 +33,12 @@ main(int argc, char *argv[])
 {
     struct hostent *host;
 
-    dns_sethostent(1, NULL);
+    dns_sethostent(1);
 
-    while ((host = dns_gethostent(NULL)))
+    while ((host = dns_gethostent()))
 	print_hosts(host);
 
-    dns_endhostent(NULL);
+    dns_endhostent();
     
     exit(0);
 }
