@@ -33,12 +33,12 @@ int main(int argc, char *argv[])
     struct passwd *pw;
 
 
-    nis_setpwent(NULL);
+    nis_setpwent();
 
-    while ((pw = nis_getpwent(NULL)) != NULL)
+    while ((pw = nis_getpwent()) != NULL)
 	print_passwd(pw);
 
-    nis_endpwent(NULL);
+    nis_endpwent();
     
     exit(0);
 }
