@@ -33,12 +33,12 @@ main(int argc, char *argv[])
     struct group *gr;
 
 
-    yp_setgrent(NULL);
+    yp_setgrent();
 
-    while ((gr = yp_getgrent(NULL)))
+    while ((gr = yp_getgrent()))
 	print_group(gr);
 
-    yp_endgrent(NULL);
+    yp_endgrent();
     
     exit(0);
 }
