@@ -34,7 +34,7 @@ main(int argc, char *argv[])
     struct group *gr;
 
 
-    gr = yp_getgrnam(argv[1], NULL);
+    gr = yp_getgrnam(argv[1]);
 
     if (gr)
 	print_group(gr);
