@@ -34,7 +34,7 @@ main(int argc, char *argv[])
     struct netent *net;
 
 
-    net = yp_getnetbyname(argv[1], NULL);
+    net = yp_getnetbyname(argv[1]);
 
     if (net)
 	print_network(net);
@@ -47,8 +47,3 @@ main(int argc, char *argv[])
 
 
 
-
-
-
-
-
